pub enum BlendEquation {
Same(BlendOperation),
Separate {
color: BlendOperation,
alpha: BlendOperation,
},
}Expand description
How to combine the values when blending
Almost all the time you’ll want BlendEquation::Same(BlendOperation::Add), but there are cases
where other blend equatiosn come in handy.
Variants
Same(BlendOperation)
Apply the same equation to the color and alpha of the blended pixels
Separate
Apply a different equation to the color and alpha channel of the blended pixels