BlendFunction

Enum BlendFunction 

pub enum BlendFunction {
    Same {
        source: BlendFactor,
        destination: BlendFactor,
    },
    Separate {
        source_color: BlendFactor,
        source_alpha: BlendFactor,
        destination_color: BlendFactor,
        destination_alpha: BlendFactor,
    },
}
The blend function controls how the source and destination are transformed

Before being passed to the BlendEquation, the source and destination are multiplied by the value determined by BlendFunction.

Variants



Same

Use the same BlendFactor on the color and alpha channels

Fields

destination: BlendFactor


Separate

Use different BlendFactors on the color and alpha channels

Fields

source_color: BlendFactor
source_alpha: BlendFactor
destination_color: BlendFactor
destination_alpha: BlendFactor