pub enum BlendFunction {
Same {
source: BlendFactor,
destination: BlendFactor,
},
Separate {
source_color: BlendFactor,
source_alpha: BlendFactor,
destination_color: BlendFactor,
destination_alpha: BlendFactor,
},
}Expand description
The blend function controls how the source and destination are transformed
Before being passed to the BlendEquation, the source and destination are multiplied by the
value determined by BlendFunction.
Variants
Same
Use the same BlendFactor on the color and alpha channels
Separate
Use different BlendFactors on the color and alpha channels
Fields

source_color: BlendFactor
source_alpha: BlendFactor
destination_color: BlendFactor
destination_alpha: BlendFactorTrait Implementations
Sourceimpl Clone for BlendFunction
impl Clone for BlendFunction
Sourcefn clone(&self) -> BlendFunction
fn clone(&self) -> BlendFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlendFunction
impl Debug for BlendFunction
Sourceimpl Default for BlendFunction
impl Default for BlendFunction
Sourcefn default() -> BlendFunction
fn default() -> BlendFunction
Returns the “default value” for a type. Read more
Sourceimpl Hash for BlendFunction
impl Hash for BlendFunction
Sourceimpl PartialEq for BlendFunction
impl PartialEq for BlendFunction
impl Copy for BlendFunction
impl Eq for BlendFunction
impl StructuralPartialEq for BlendFunction